pub struct MultiIndex<K: Send + Sync> { /* private fields */ }Implementations
Sourceimpl<K: Clone + Eq + Hash + Debug + Send + Sync> MultiIndex<K>
impl<K: Clone + Eq + Hash + Debug + Send + Sync> MultiIndex<K>
pub fn new<R: Rng + Sized>( dimension: usize, index_count: u8, hyperplane_count: u8, rng: &mut R, ) -> MultiIndex<K>
Sourcepub fn autotune_planes<R: Rng + Sized>(
dimension: usize,
group_size: f32,
vectors: &Vec<Vec<f32>>,
rng: &mut R,
) -> u8
pub fn autotune_planes<R: Rng + Sized>( dimension: usize, group_size: f32, vectors: &Vec<Vec<f32>>, rng: &mut R, ) -> u8
Given a set of vectors, discover the best index count and plane count to use to achieve a particular group size
pub fn nearest<F>( &self, point: &Vec<f32>, count: usize, get_dist: F, ) -> Vec<DistanceNode<K>>
pub fn nearest_points(&self, point: &Vec<f32>) -> Vec<K>
pub fn add(&mut self, key: K, vector: &Vec<f32>)
pub fn dimensions(&self) -> usize
pub fn planes_len(&self) -> usize
pub fn indices_len(&self) -> usize